import ij.plugin.*;
import ij.*;
import ij.gui.*;
import ij.process.*;
import java.awt.*;
import java.awt.image.*;
import java.awt.event.*;

/**
	Opens an image window with a panel containing "Invert" and "Flip"
	buttons. If no images are open, creates a blank 400x200 byte image, 
	otherwise, the current image is cloned.
*/
public class Panel_Window implements PlugIn {

	static final int WIDTH = 400;
	static final int HEIGHT = 200;

	public void run(String arg) {
		ImagePlus imp1 = WindowManager.getCurrentImage();
		ImageProcessor ip;
		if (imp1==null) {
			ip = new ByteProcessor(WIDTH, HEIGHT);
			ip.setColor(Color.white);
			ip.fill();
		} else {
			ip = imp1.getProcessor();
			ip.setRoi(null);
			ip = ip.crop(); // clone pixel data
		}
		ImagePlus imp2 = new ImagePlus("Panel Window", ip);
		CustomCanvas cc = new CustomCanvas(imp2);
		new CustomWindow(imp2, cc);
	}

}


class CustomCanvas extends ImageCanvas {

	CustomCanvas(ImagePlus imp) {
		super(imp);
	}

	public void mousePressed(MouseEvent e) {
		super.mousePressed(e);
		IJ.write("mousePressed: ("+offScreenX(e.getX())+","+offScreenY(e.getY())+")");
	}

}


class CustomWindow extends ImageWindow implements ActionListener {

	private Button button1, button2;
   
	CustomWindow(ImagePlus imp, ImageCanvas ic) {
		super(imp, ic);
		addPanel();
	}

	void addPanel() {
		Panel panel = new Panel();
		panel.setLayout(new FlowLayout(FlowLayout.RIGHT));
		button1 = new Button(" Invert ");
		button1.addActionListener(this);
		panel.add(button1);
		button2 = new Button(" Flip ");
		button2.addActionListener(this);
		panel.add(button2);
		add(panel);
		pack();
	}
  
	public void actionPerformed(ActionEvent e) {
		Object b = e.getSource();
		if (b==button1) {
			imp.getProcessor().invert();
			imp.updateAndDraw();
		} else {
			imp.getProcessor().flipVertical();
			imp.updateAndDraw();
		}

	}
	
}


